qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PULL 20/30] simplebench: rename ascii() to results_to_text()


From: Max Reitz
Subject: [PULL 20/30] simplebench: rename ascii() to results_to_text()
Date: Fri, 18 Dec 2020 16:12:39 +0100

From: Vladimir Sementsov-Ogievskiy <vsementsov@virtuozzo.com>

Next patch will use utf8 plus-minus symbol, let's use more generic (and
more readable) name.

Signed-off-by: Vladimir Sementsov-Ogievskiy <vsementsov@virtuozzo.com>
Message-Id: <20201021145859.11201-17-vsementsov@virtuozzo.com>
Reviewed-by: Max Reitz <mreitz@redhat.com>
Signed-off-by: Max Reitz <mreitz@redhat.com>
---
 scripts/simplebench/bench-example.py   |  2 +-
 scripts/simplebench/bench_write_req.py |  2 +-
 scripts/simplebench/simplebench.py     | 10 +++++-----
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/scripts/simplebench/bench-example.py 
b/scripts/simplebench/bench-example.py
index c642a5b891..f24cf22fe9 100644
--- a/scripts/simplebench/bench-example.py
+++ b/scripts/simplebench/bench-example.py
@@ -77,4 +77,4 @@ test_envs = [
 ]
 
 result = simplebench.bench(bench_func, test_envs, test_cases, count=3)
-print(simplebench.ascii(result))
+print(simplebench.results_to_text(result))
diff --git a/scripts/simplebench/bench_write_req.py 
b/scripts/simplebench/bench_write_req.py
index ca1178fd68..e175bcd7a4 100755
--- a/scripts/simplebench/bench_write_req.py
+++ b/scripts/simplebench/bench_write_req.py
@@ -167,4 +167,4 @@ if __name__ == '__main__':
 
     result = simplebench.bench(bench_func, test_envs, test_cases, count=3,
                                initial_run=False)
-    print(simplebench.ascii(result))
+    print(simplebench.results_to_text(result))
diff --git a/scripts/simplebench/simplebench.py 
b/scripts/simplebench/simplebench.py
index 55ec1ad5db..aa74b78a04 100644
--- a/scripts/simplebench/simplebench.py
+++ b/scripts/simplebench/simplebench.py
@@ -79,8 +79,8 @@ def bench_one(test_func, test_env, test_case, count=5, 
initial_run=True):
     return result
 
 
-def ascii_one(result):
-    """Return ASCII representation of bench_one() returned dict."""
+def result_to_text(result):
+    """Return text representation of bench_one() returned dict."""
     if 'average' in result:
         s = '{:.2f} +- {:.2f}'.format(result['average'], result['stdev'])
         if 'n-failed' in result:
@@ -127,8 +127,8 @@ def bench(test_func, test_envs, test_cases, *args, **vargs):
     return results
 
 
-def ascii(results):
-    """Return ASCII representation of bench() returned dict."""
+def results_to_text(results):
+    """Return text representation of bench() returned dict."""
     from tabulate import tabulate
 
     dim = None
@@ -141,7 +141,7 @@ def ascii(results):
                 dim = res['dimension']
             else:
                 assert dim == res['dimension']
-            row.append(ascii_one(res))
+            row.append(result_to_text(res))
         tab.append(row)
 
     return f'All results are in {dim}\n\n' + tabulate(tab)
-- 
2.29.2




reply via email to

[Prev in Thread] Current Thread [Next in Thread]